# PANDDA Processing Output

## Summary of Processing of Datasets

| Data Quality | Identical Structure | Model Quality | RMSD to Reference | Overall | Interesting Areas
Dataset x425 | OK | OK | RFree: 0.231 | RMSD: 0.111 | Analysed |  | Complete
Dataset x427 | OK | OK | RFree: 0.215 | RMSD: 0.078 | Analysed |  | Complete
Dataset x428 | OK | OK | RFree: 0.219 | RMSD: 0.036 | Analysed |  | Complete
Dataset x430 | OK | OK | RFree: 0.211 | RMSD: 0.064 | Analysed |  | Complete
Dataset x431 | OK | OK | RFree: 0.211 | RMSD: 0.053 | Analysed |  | Complete
Dataset x432 | OK | OK | RFree: 0.219 | RMSD: 0.081 | Analysed |  | Complete
Dataset x433 | OK | OK | RFree: 0.209 | RMSD: 0.052 | Analysed |  | Complete
Dataset x434 | OK | OK | RFree: 0.204 | RMSD: 0.15 | Analysed | Clusters Found | Complete
Dataset x435 | OK | OK | RFree: 0.205 | RMSD: 0.145 | Analysed |  | Complete
Dataset x436 | OK | OK | RFree: 0.21 | RMSD: 0.097 | Analysed |  | Complete
Dataset x437 | OK | OK | RFree: 0.211 | RMSD: 0.067 | Analysed |  | Complete
Dataset x438 | OK | OK | RFree: 0.232 | RMSD: 0.07 | Analysed |  | Complete
Dataset x439 | OK | OK | RFree: 0.202 | RMSD: 0.093 | Analysed |  | Complete
Dataset x440 | OK | OK | RFree: 0.21 | RMSD: 0.037 | Analysed |  | Complete
Dataset x442 | OK | OK | RFree: 0.206 | RMSD: 0.086 | Analysed |  | Complete
Dataset x443 | OK | OK | RFree: 0.22 | RMSD: 0.082 | Analysed |  | Complete
Dataset x446 | OK | OK | RFree: 0.227 | RMSD: 0.25 | Analysed |  | Complete
Dataset x447 | OK | OK | RFree: 0.209 | RMSD: 0.117 | Analysed | Clusters Found | Complete
Dataset x448 | OK | OK | RFree: 0.216 | RMSD: 0.135 | Analysed | Clusters Found | Complete
Dataset x449 | OK | OK | RFree: 0.216 | RMSD: 0.068 | Analysed |  | Complete
Dataset x451 | OK | OK | RFree: 0.221 | RMSD: 0.137 | Analysed | Clusters Found | Complete
Dataset x452 | OK | OK | RFree: 0.224 | RMSD: 0.051 | Analysed |  | Complete
Dataset x453 | OK | OK | RFree: 0.212 | RMSD: 0.056 | Analysed |  | Complete
Dataset x454 | OK | OK | RFree: 0.21 | RMSD: 0.113 | Analysed |  | Complete
Dataset x455 | OK | OK | RFree: 0.219 | RMSD: 0.051 | Analysed |  | Complete
Dataset x456 | OK | OK | RFree: 0.212 | RMSD: 0.054 | Analysed |  | Complete
Dataset x457 | OK | OK | RFree: 0.226 | RMSD: 0.127 | Analysed |  | Complete
Dataset x458 | OK | OK | RFree: 0.229 | RMSD: 0.103 | Analysed |  | Complete
Dataset x459 | OK | OK | RFree: 0.219 | RMSD: 0.086 | Analysed |  | Complete
Dataset x462 | OK | OK | RFree: 0.202 | RMSD: 0.112 | Analysed |  | Complete
Dataset x463 | OK | OK | RFree: 0.214 | RMSD: 0.222 | Analysed | Clusters Found | Complete
Dataset x464 | OK | OK | RFree: 0.239 | RMSD: 0.086 | Analysed |  | Complete
Dataset x465 | OK | OK | RFree: 0.211 | RMSD: 0.051 | Analysed |  | Complete
Dataset x467 | OK | OK | RFree: 0.212 | RMSD: 0.036 | Analysed |  | Complete
Dataset x468 | OK | OK | RFree: 0.261 | RMSD: 0.079 | Analysed |  | Complete
Dataset x469 | OK | OK | RFree: 0.244 | RMSD: 0.093 | Analysed |  | Complete
Dataset x470 | OK | OK | RFree: 0.26 | RMSD: 0.113 | Analysed | Clusters Found | Complete
Dataset x471 | OK | OK | RFree: 0.246 | RMSD: 0.097 | Analysed |  | Complete
Dataset x472 | OK | OK | RFree: 0.229 | RMSD: 0.079 | Analysed |  | Complete
Dataset x473 | OK | OK | RFree: 0.207 | RMSD: 0.124 | Analysed |  | Complete
Dataset x474 | OK | OK | RFree: 0.219 | RMSD: 0.152 | Analysed |  | Complete
Dataset x475 | OK | OK | RFree: 0.199 | RMSD: 0.154 | Analysed | Clusters Found | Complete
Dataset x476 | OK | OK | RFree: 0.27 | RMSD: 0.117 | Analysed |  | Complete
Dataset x477 | OK | OK | RFree: 0.206 | RMSD: 0.11 | Analysed |  | Complete
Dataset x478 | OK | OK | RFree: 0.212 | RMSD: 0.201 | Analysed | Clusters Found | Complete
Dataset x479 | OK | OK | RFree: 0.205 | RMSD: 0.104 | Analysed |  | Complete
Dataset x480 | OK | OK | RFree: 0.205 | RMSD: 0.177 | Analysed | Clusters Found | Complete
Dataset x481 | OK | OK | RFree: 0.209 | RMSD: 0.229 | Analysed | Clusters Found | Complete
Dataset x482 | OK | OK | RFree: 0.238 | RMSD: 0.157 | Analysed |  | Complete
Dataset x483 | OK | OK | RFree: 0.213 | RMSD: 0.046 | Analysed |  | Complete
Dataset x484 | OK | OK | RFree: 0.218 | RMSD: 0.063 | Analysed |  | Complete
Dataset x485 | OK | OK | RFree: 0.217 | RMSD: 0.08 | Analysed |  | Complete
Dataset x486 | OK | OK | RFree: 0.21 | RMSD: 0.1 | Analysed |  | Complete
Dataset x487 | OK | OK | RFree: 0.209 | RMSD: 0.103 | Analysed |  | Complete
Dataset x488 | OK | OK | RFree: 0.213 | RMSD: 0.115 | Analysed |  | Complete
Dataset x489 | OK | OK | RFree: 0.218 | RMSD: 0.101 | Analysed | Clusters Found | Complete
Dataset x490 | OK | OK | RFree: 0.212 | RMSD: 0.062 | Analysed |  | Complete
Dataset x491 | OK | OK | RFree: 0.233 | RMSD: 0.096 | Analysed |  | Complete
Dataset x492 | OK | OK | RFree: 0.208 | RMSD: 0.151 | Analysed | Clusters Found | Complete
Dataset x494 | OK | OK | RFree: 0.21 | RMSD: 0.075 | Analysed |  | Complete
Dataset x495 | OK | OK | RFree: 0.213 | RMSD: 0.061 | Analysed |  | Complete
Dataset x496 | OK | OK | RFree: 0.218 | RMSD: 0.069 | Analysed |  | Complete
Dataset x497 | OK | OK | RFree: 0.204 | RMSD: 0.072 | Analysed |  | Complete
Dataset x498 | OK | OK | RFree: 0.206 | RMSD: 0.136 | Analysed |  | Complete
Dataset x499 | OK | OK | RFree: 0.234 | RMSD: 0.122 | Analysed |  | Complete
Dataset x500 | OK | OK | RFree: 0.214 | RMSD: 0.043 | Analysed |  | Complete
Dataset x501 | OK | OK | RFree: 0.213 | RMSD: 0.053 | Analysed |  | Complete
Dataset x502 | OK | OK | RFree: 0.215 | RMSD: 0.151 | Analysed |  | Complete
Dataset x503 | OK | OK | RFree: 0.209 | RMSD: 0.18 | Analysed | Clusters Found | Complete
Dataset x504 | OK | OK | RFree: 0.211 | RMSD: 0.104 | Analysed |  | Complete
Dataset x505 | OK | OK | RFree: 0.212 | RMSD: 0.075 | Analysed | Clusters Found | Complete
Dataset x506 | OK | OK | RFree: 0.22 | RMSD: 0.076 | Analysed | Clusters Found | Complete
Dataset x507 | OK | OK | RFree: 0.217 | RMSD: 0.095 | Analysed |  | Complete
Dataset x508 | OK | OK | RFree: 0.215 | RMSD: 0.083 | Analysed |  | Complete
Dataset x509 | OK | OK | RFree: 0.231 | RMSD: 0.229 | Analysed | Clusters Found | Complete
Dataset x510 | OK | OK | RFree: 0.213 | RMSD: 0.193 | Analysed |  | Complete
Dataset x511 | OK | OK | RFree: 0.218 | RMSD: 0.081 | Analysed |  | Complete
Dataset x512 | OK | OK | RFree: 0.216 | RMSD: 0.072 | Analysed | Clusters Found | Complete
Dataset x514 | OK | OK | RFree: 0.21 | RMSD: 0.041 | Analysed |  | Complete
Dataset x515 | OK | OK | RFree: 0.21 | RMSD: 0.043 | Analysed |  | Complete
Dataset x516 | OK | OK | RFree: 0.208 | RMSD: 0.066 | Analysed |  | Complete
Dataset x518 | OK | OK | RFree: 0.225 | RMSD: 0.066 | Analysed |  | Complete
Dataset x519 | OK | OK | RFree: 0.205 | RMSD: 0.09 | Analysed |  | Complete
Dataset x520 | OK | OK | RFree: 0.213 | RMSD: 0.047 | Analysed |  | Complete
Dataset x521 | OK | OK | RFree: 0.208 | RMSD: 0.119 | Analysed |  | Complete
Dataset x523 | OK | OK | RFree: 0.22 | RMSD: 0.091 | Analysed |  | Complete
Dataset x525 | OK | OK | RFree: 0.219 | RMSD: 0.072 | Analysed |  | Complete
Dataset x526 | OK | OK | RFree: 0.212 | RMSD: 0.064 | Analysed |  | Complete
Dataset x527 | OK | OK | RFree: 0.216 | RMSD: 0.08 | Analysed |  | Complete
Dataset x528 | OK | OK | RFree: 0.21 | RMSD: 0.061 | Analysed |  | Complete
Dataset x529 | OK | OK | RFree: 0.202 | RMSD: 0.119 | Analysed | Clusters Found | Complete
Dataset x530 | OK | OK | RFree: 0.215 | RMSD: 0.06 | Analysed |  | Complete
Dataset x531 | OK | OK | RFree: 0.216 | RMSD: 0.096 | Analysed |  | Complete
Dataset x532 | OK | OK | RFree: 0.224 | RMSD: 0.072 | Analysed |  | Complete
Dataset x533 | OK | OK | RFree: 0.226 | RMSD: 0.059 | Analysed |  | Complete
Dataset x534 | OK | OK | RFree: 0.218 | RMSD: 0.064 | Analysed |  | Complete
Dataset x535 | OK | OK | RFree: 0.218 | RMSD: 0.066 | Analysed |  | Complete
Dataset x536 | OK | OK | RFree: 0.218 | RMSD: 0.148 | Analysed | Clusters Found | Complete
Dataset x537 | OK | OK | RFree: 0.223 | RMSD: 0.062 | Analysed |  | Complete
Dataset x538 | OK | OK | RFree: 0.222 | RMSD: 0.053 | Analysed | Clusters Found | Complete
Dataset x539 | OK | OK | RFree: 0.218 | RMSD: 0.067 | Analysed |  | Complete
Dataset x540 | OK | OK | RFree: 0.218 | RMSD: 0.048 | Analysed |  | Complete
Dataset x541 | OK | OK | RFree: 0.226 | RMSD: 0.079 | Analysed |  | Complete
Dataset x542 | OK | OK | RFree: 0.216 | RMSD: 0.149 | Analysed |  | Complete
Dataset x543 | OK | OK | RFree: 0.218 | RMSD: 0.146 | Analysed |  | Complete
Dataset x544 | OK | OK | RFree: 0.223 | RMSD: 0.058 | Analysed |  | Complete
Dataset x545 | OK | OK | RFree: 0.209 | RMSD: 0.136 | Analysed |  | Complete
Dataset x546 | OK | OK | RFree: 0.221 | RMSD: 0.082 | Analysed |  | Complete
Dataset x547 | OK | OK | RFree: 0.24 | RMSD: 0.197 | Analysed |  | Complete
Dataset x548 | OK | OK | RFree: 0.229 | RMSD: 0.051 | Analysed |  | Complete
Dataset x549 | OK | OK | RFree: 0.213 | RMSD: 0.057 | Analysed |  | Complete
Dataset x550 | OK | OK | RFree: 0.212 | RMSD: 0.057 | Analysed |  | Complete
Dataset x552 | OK | OK | RFree: 0.216 | RMSD: 0.079 | Analysed |  | Complete
Dataset x553 | OK | OK | RFree: 0.217 | RMSD: 0.082 | Analysed |  | Complete
Dataset x554 | OK | OK | RFree: 0.225 | RMSD: 0.1 | Analysed |  | Complete
Dataset x555 | OK | OK | RFree: 0.225 | RMSD: 0.099 | Analysed |  | Complete
Dataset x556 | OK | OK | RFree: 0.219 | RMSD: 0.082 | Analysed | Clusters Found | Complete
Dataset x557 | OK | OK | RFree: 0.223 | RMSD: 0.045 | Analysed |  | Complete
Dataset x558 | OK | OK | RFree: 0.222 | RMSD: 0.062 | Analysed |  | Complete
Dataset x559 | OK | OK | RFree: 0.232 | RMSD: 0.152 | Analysed | Clusters Found | Complete
Dataset x560 | OK | OK | RFree: 0.217 | RMSD: 0.247 | Analysed | Clusters Found | Complete
Dataset x561 | OK | OK | RFree: 0.217 | RMSD: 0.074 | Analysed |  | Complete
Dataset x562 | OK | OK | RFree: 0.247 | RMSD: 0.114 | Analysed |  | Complete
Dataset x563 | OK | OK | RFree: 0.226 | RMSD: 0.102 | Analysed |  | Complete
Dataset x564 | OK | OK | RFree: 0.215 | RMSD: 0.063 | Analysed |  | Complete
Dataset x575 | OK | OK | RFree: 0.216 | RMSD: 0.16 | Analysed | Clusters Found | Complete
Dataset x577 | OK | OK | RFree: 0.219 | RMSD: 0.063 | Analysed |  | Complete
Dataset x578 | OK | OK | RFree: 0.218 | RMSD: 0.052 | Analysed |  | Complete
Dataset x579 | OK | OK | RFree: 0.22 | RMSD: 0.073 | Analysed |  | Complete
Dataset x580 | OK | OK | RFree: 0.229 | RMSD: 0.072 | Analysed |  | Complete
Dataset x581 | OK | OK | RFree: 0.219 | RMSD: 0.084 | Analysed |  | Complete
Dataset x582 | OK | OK | RFree: 0.217 | RMSD: 0.038 | Analysed |  | Complete
Dataset x583 | OK | OK | RFree: 0.221 | RMSD: 0.161 | Analysed | Clusters Found | Complete
Dataset x584 | OK | OK | RFree: 0.22 | RMSD: 0.093 | Analysed |  | Complete
Dataset x585 | OK | OK | RFree: 0.235 | RMSD: 0.072 | Analysed |  | Complete
Dataset x586 | OK | OK | RFree: 0.221 | RMSD: 0.076 | Analysed |  | Complete
Dataset x589 | OK | OK | RFree: 0.221 | RMSD: 0.049 | Analysed |  | Complete
Dataset x590 | OK | OK | RFree: 0.229 | RMSD: 0.119 | Analysed |  | Complete
Dataset x592 | OK | OK | RFree: 0.216 | RMSD: 0.144 | Analysed | Clusters Found | Complete
Dataset x593 | OK | OK | RFree: 0.212 | RMSD: 0.094 | Analysed |  | Complete
Dataset x594 | OK | OK | RFree: 0.249 | RMSD: 0.133 | Analysed |  | Complete
Dataset x595 | OK | OK | RFree: 0.219 | RMSD: 0.089 | Analysed |  | Complete
Dataset x596 | OK | OK | RFree: 0.263 | RMSD: 0.088 | Analysed |  | Complete
Dataset x598 | OK | OK | RFree: 0.22 | RMSD: 0.078 | Analysed |  | Complete
Dataset x599 | OK | OK | RFree: 0.223 | RMSD: 0.11 | Analysed |  | Complete
Dataset x600 | OK | OK | RFree: 0.22 | RMSD: 0.048 | Analysed |  | Complete
Dataset x601 | OK | OK | RFree: 0.215 | RMSD: 0.087 | Analysed |  | Complete
Dataset x602 | OK | OK | RFree: 0.228 | RMSD: 0.058 | Analysed |  | Complete
Dataset x603 | OK | OK | RFree: 0.222 | RMSD: 0.134 | Analysed | Clusters Found | Complete
Dataset x604 | OK | OK | RFree: 0.224 | RMSD: 0.065 | Analysed |  | Complete
Dataset x605 | OK | OK | RFree: 0.216 | RMSD: 0.07 | Analysed |  | Complete
Dataset x606 | OK | OK | RFree: 0.224 | RMSD: 0.055 | Analysed |  | Complete
Dataset x608 | OK | OK | RFree: 0.213 | RMSD: 0.14 | Analysed |  | Complete
Dataset x609 | OK | OK | RFree: 0.206 | RMSD: 0.173 | Analysed | Clusters Found | Complete
Dataset x610 | OK | OK | RFree: 0.209 | RMSD: 0.157 | Analysed |  | Complete
Dataset x611 | OK | OK | RFree: 0.208 | RMSD: 0.105 | Analysed |  | Complete
Dataset x612 | OK | OK | RFree: 0.213 | RMSD: 0.126 | Analysed | Clusters Found | Complete
Dataset x613 | OK | OK | RFree: 0.213 | RMSD: 0.182 | Analysed |  | Complete
Dataset x614 | OK | OK | RFree: 0.212 | RMSD: 0.081 | Analysed | Clusters Found | Complete
Dataset x615 | OK | OK | RFree: 0.211 | RMSD: 0.084 | Analysed |  | Complete
Dataset x616 | OK | OK | RFree: 0.211 | RMSD: 0.162 | Analysed |  | Complete
Dataset x617 | OK | OK | RFree: 0.215 | RMSD: 0.145 | Analysed |  | Complete
Dataset x618 | OK | OK | RFree: 0.213 | RMSD: 0.126 | Analysed |  | Complete
Dataset x619 | OK | OK | RFree: 0.267 | RMSD: 0.135 | Analysed |  | Complete
Dataset x620 | OK | OK | RFree: 0.224 | RMSD: 0.113 | Analysed |  | Complete
Dataset x621 | OK | OK | RFree: 0.216 | RMSD: 0.116 | Analysed |  | Complete
Dataset x639 | OK | OK | RFree: 0.223 | RMSD: 0.112 | Analysed |  | Complete
Dataset x640 | OK | OK | RFree: 0.222 | RMSD: 0.081 | Analysed |  | Complete
Dataset x641 | OK | OK | RFree: 0.213 | RMSD: 0.08 | Analysed |  | Complete
Dataset x642 | OK | OK | RFree: 0.224 | RMSD: 0.087 | Analysed |  | Complete
Dataset x643 | OK | OK | RFree: 0.224 | RMSD: 0.039 | Analysed |  | Complete
Dataset x644 | OK | OK | RFree: 0.227 | RMSD: 0.058 | Analysed |  | Complete
Dataset x645 | OK | OK | RFree: 0.246 | RMSD: 0.098 | Analysed |  | Complete
Dataset x646 | OK | OK | RFree: 0.222 | RMSD: 0.074 | Analysed |  | Complete
Dataset x647 | OK | OK | RFree: 0.225 | RMSD: 0.073 | Analysed |  | Complete
Dataset x648 | OK | OK | RFree: 0.255 | RMSD: 0.104 | Analysed |  | Complete
Dataset x649 | OK | OK | RFree: 0.221 | RMSD: 0.053 | Analysed |  | Complete
Dataset x650 | OK | OK | RFree: 0.22 | RMSD: 0.063 | Analysed |  | Complete
Dataset x651 | OK | OK | RFree: 0.232 | RMSD: 0.128 | Analysed | Clusters Found | Complete
Dataset x652 | OK | OK | RFree: 0.218 | RMSD: 0.115 | Analysed |  | Complete
Dataset x653 | OK | OK | RFree: 0.213 | RMSD: 0.049 | Analysed |  | Complete
Dataset x654 | OK | OK | RFree: 0.217 | RMSD: 0.059 | Analysed |  | Complete
Dataset x655 | OK | OK | RFree: 0.216 | RMSD: 0.072 | Analysed |  | Complete
Dataset x657 | OK | OK | RFree: 0.223 | RMSD: 0.231 | Analysed |  | Complete
Dataset x659 | OK | OK | RFree: 0.215 | RMSD: 0.139 | Analysed |  | Complete
Dataset x660 | OK | OK | RFree: 0.224 | RMSD: 0.117 | Analysed | Clusters Found | Complete
Dataset x661 | OK | OK | RFree: 0.227 | RMSD: 0.11 | Analysed |  | Complete
Dataset x662 | OK | OK | RFree: 0.225 | RMSD: 0.124 | Analysed |  | Complete
Dataset x665 | OK | OK | RFree: 0.219 | RMSD: 0.051 | Analysed |  | Complete
Dataset x666 | OK | OK | RFree: 0.25 | RMSD: 0.072 | Analysed |  | Complete
Dataset x667 | OK | OK | RFree: 0.218 | RMSD: 0.09 | Analysed |  | Complete
Dataset x668 | OK | OK | RFree: 0.212 | RMSD: 0.072 | Analysed |  | Complete
Dataset x669 | OK | OK | RFree: 0.265 | RMSD: 0.155 | Analysed |  | Complete
Dataset x670 | OK | OK | RFree: 0.218 | RMSD: 0.059 | Analysed |  | Complete
Dataset x671 | OK | OK | RFree: 0.217 | RMSD: 0.071 | Analysed |  | Complete
Dataset x674 | OK | OK | RFree: 0.221 | RMSD: 0.05 | Analysed |  | Complete
Dataset x675 | OK | OK | RFree: 0.225 | RMSD: 0.061 | Analysed |  | Complete
Dataset x676 | OK | OK | RFree: 0.218 | RMSD: 0.089 | Analysed |  | Complete
Dataset x677 | OK | OK | RFree: 0.219 | RMSD: 0.174 | Analysed |  | Complete
Dataset x678 | OK | OK | RFree: 0.22 | RMSD: 0.094 | Analysed |  | Complete